==> sspse_1.1.0-1.tar.gz: sspse/src/posteriorcmpwpvis_binomial.h <==
#ifndef POSTERIORCMPWPVIS_BINOMIAL_H
#define POSTERIORCMPWPVIS_BINOMIAL_H

void gcmpwpvis_binomial (int *pop,
            int *K, 
            int *n, 
            int *samplesize, int *burnin, int *interval,
            double *mu, double *dfmu, 
            double *sigma, double *dfsigma,
	    double *lnlam, double *nu,
            double *beta0muprior, double *beta0sigmaprior, 
            double *betatmuprior, double *betatsigmaprior, 
            double *lmemmu, double *memdfmu,
            double *memnu, double *memdfnu,
            double *memod,
            int *Npi,
            int *srd, 
            int *numrec, 
            double *rectime,
            int *maxcoupons,
            double *lnlamproposal, 
            double *nuproposal, 
            double *beta0proposal, double *betatproposal, 
            double *lmemmuproposal, double *memnuproposal,
            int *N, int *maxN, 
            double *sample, 
            int *vsample, 
            double *posu, 
            double *posd, 
            double *lpriorm, 
            int *burnintheta,
            int *burninbeta,
            int *verbose
         );

void MHwpmem_binomial (int *d, int *n, int *K,
            double *beta0, double *beta0sd, double *betat, double *betatsd, 
            double *lmemmu, double *memdfmu,
            double *memnu, double *memdfnu,
            int *srd, 
            int *numrec, 
            double *rectime,
            int *maxcoupons,
            double *beta0proposal, double *betatproposal, 
            double *lmemmuproposal, double *memnuproposal, 
            double *beta0sample, double *betatsample,
            double *lmemmusample, double *memnusample,
            int *samplesize, int *staken, int *burnin, int *interval,
            int *verbose
         );

void MHcmptheta (int *Nk, int *K,
            double *mu, double *dfmu, 
            double *sigma,  double *dfsigma,
            double *lnlamproposal, 
            double *nuproposal, 
            int *N, int *Npi, double *psample,
            double *lnlamsample, double *nusample,
            int *samplesize, int *staken, int *burnintheta, int *interval,
            int *verbose
         );

#endif /* POSTERIORCMPWPVIS_BINOMIAL_H */

==> sspse_1.1.0-4.tar.gz: sspse/src/posteriorcmpwpvis_binomial.h <==
#ifndef POSTERIORCMPWPVIS_BINOMIAL_H
#define POSTERIORCMPWPVIS_BINOMIAL_H

void gcmpwpvis_binomial (int *pop,
            int *K, 
            int *n, 
            int *samplesize, int *warmup, int *interval,
            double *mu, double *dfmu, 
            double *sigma, double *dfsigma,
	    double *lnlam, double *nu,
            double *beta0muprior, double *beta0sigmaprior, 
            double *betatmuprior, double *betatsigmaprior, 
            double *lmemmu, double *memdfmu,
            double *memnu, double *memdfnu,
            double *memod,
            int *Npi,
            int *srd, 
            int *numrec, 
            double *rectime,
            int *maxcoupons,
            double *lnlamproposal, 
            double *nuproposal, 
            double *beta0proposal, double *betatproposal, 
            double *lmemmuproposal, double *memnuproposal,
            int *N, int *maxN, 
            double *sample, 
            int *vsample, 
            double *posu, 
            double *posd, 
            double *lpriorm, 
            int *warmuptheta,
            int *warmupbeta,
            int *verbose
         );

void MHwpmem_binomial (int *d, int *n, int *K,
            double *beta0, double *beta0sd, double *betat, double *betatsd, 
            double *lmemmu, double *memdfmu,
            double *memnu, double *memdfnu,
            int *srd, 
            int *numrec, 
            double *rectime,
            int *maxcoupons,
            double *beta0proposal, double *betatproposal, 
            double *lmemmuproposal, double *memnuproposal, 
            double *beta0sample, double *betatsample,
            double *lmemmusample, double *memnusample,
            int *samplesize, int *staken, int *warmup, int *interval,
            int *verbose
         );

void MHcmptheta (int *Nk, int *K,
            double *mu, double *dfmu, 
            double *sigma,  double *dfsigma,
            double *lnlamproposal, 
            double *nuproposal, 
            int *N, int *Npi, double *psample,
            double *lnlamsample, double *nusample,
            int *samplesize, int *staken, int *warmuptheta, int *interval,
            int *verbose
         );

#endif /* POSTERIORCMPWPVIS_BINOMIAL_H */
